@@ -38,7 +38,8 @@ m = Symbol("m", real=True)
 
 def u(p, r):
     """ p = (p1, p2, p3); r = 0,1 """
-    assert r in [1, 2]
+    if r not in [1, 2]:
+        raise ValueError("Value of r should lie between 1 and 2")
     p1, p2, p3 = p
     if r == 1:
         ksi = Matrix([[1], [0]])
@@ -52,7 +53,8 @@ def u(p, r):
 
 def v(p, r):
     """ p = (p1, p2, p3); r = 0,1 """
-    assert r in [1, 2]
+    if r not in [1, 2]:
+        raise ValueError("Value of r should lie between 1 and 2")
     p1, p2, p3 = p
     if r == 1:
         ksi = Matrix([[1], [0]])
@@ -113,7 +115,8 @@ def main():
              v(kp, 1) ) for mu in range(4)]
     M = M0[0] + M0[1] + M0[2] + M0[3]
     M = M[0]
-    assert isinstance(M, Basic)
+    if not isinstance(M, Basic):
+        raise TypeError("Invalid type of variable")
     #print M
     #print simplify(M)
 
