@@ -138,7 +138,7 @@ def prepare_apt():
     sudo("apt-get -qq update")
     sudo("apt-get -y install git python3 make python-virtualenv zip python-dev")
     # Needed to build the docs
-    sudo("apt-get -y install graphviz inkscape texlive texlive-xetex texlive-fonts-recommended texlive-latex-extra")
+    sudo("apt-get -y install graphviz inkscape texlive texlive-xetex texlive-fonts-recommended texlive-latex-extra librsvg2-bin")
     # Our Ubuntu is too old to include Python 3.3
     sudo("apt-get -y install python-software-properties")
     sudo("add-apt-repository -y ppa:fkrull/deadsnakes")
@@ -861,7 +861,7 @@ def update_docs(docs_location=None):
 
     print("Writing new version to releases.txt")
     with open(os.path.join(docs_location, "releases.txt"), 'a') as f:
-        f.write("{version}:SymPy {version}".format(version=current_version))
+        f.write("{version}:SymPy {version}\n".format(version=current_version))
 
     print("Generating indexes")
     local("cd {docs_location} && ./generate_indexes.py".format(docs_location=docs_location))
@@ -982,6 +982,8 @@ def test_pypi(release='2'):
 
     version = get_sympy_version()
 
+    release = str(release)
+
     if release not in {'2', '3'}: # TODO: Add win32
         raise ValueError("release must be one of '2', '3', not %s" % release)
 
