@@ -57,10 +57,10 @@ def __sympifyit(func, arg, retval=None):
     """
 
     # we support f(a,b) only
-    assert get_function_code(func).co_argcount
+    if not get_function_code(func).co_argcount:
+        raise LookupError("func not found")
     # only b is _sympified
     assert get_function_code(func).co_varnames[1] == arg
-
     if retval is None:
         @wraps(func)
         def __sympifyit_wrapper(a, b):
