@@ -10,7 +10,6 @@ from sympy.core.numbers import Float
 from sympy.core.compatibility import iterable, with_metaclass
 
 from sympy.mpmath import mpi, mpf
-from sympy.assumptions import ask
 from sympy.logic.boolalg import And, Or, true, false
 
 from sympy.utilities import default_sort_key
@@ -232,6 +231,57 @@ class Set(Basic):
         """
         return self._measure
 
+    @property
+    def boundary(self):
+        """
+        The boundary or frontier of a set
+
+        A point x is on the boundary of a set S if
+
+        1.  x is in the closure of S.
+            I.e. Every neighborhood of x contains a point in S.
+        2.  x is not in the interior of S.
+            I.e. There does not exist an open set centered on x contained
+            entirely within S.
+
+        There are the points on the outer rim of S.  If S is open then these
+        points need not actually be contained within S.
+
+        For example, the boundary of an interval is its start and end points.
+        This is true regardless of whether or not the interval is open.
+
+        >>> from sympy import Interval
+        >>> Interval(0, 1).boundary
+        {0, 1}
+
+        >>> Interval(0, 1, True, False).boundary
+        {0, 1}
+        """
+        return self._boundary
+
+    @property
+    def is_open(self):
+        if not Intersection(self, self.boundary):
+            return True
+        # We can't confidently claim that an intersection exists
+        return None
+
+    @property
+    def is_closed(self):
+        return self.subset(self.boundary)
+
+    @property
+    def closure(self):
+        return self + self.boundary
+
+    @property
+    def interior(self):
+        return self - self.boundary
+
+    @property
+    def _boundary(self):
+        raise NotImplementedError()
+
     def _eval_imageset(self, f):
         from sympy.sets.fancysets import ImageSet
         return ImageSet(f, self)
@@ -267,6 +317,7 @@ class Set(Basic):
         return self.complement
 
     def __contains__(self, other):
+        from sympy.assumptions import ask
         symb = self.contains(other)
         result = ask(symb)
         if result is None:
@@ -333,6 +384,9 @@ class ProductSet(Set):
         if EmptySet() in sets or len(sets) == 0:
             return EmptySet()
 
+        if len(sets) == 1:
+            return sets[0]
+
         return Basic.__new__(cls, *sets, **assumptions)
 
     def _contains(self, element):
@@ -369,6 +423,19 @@ class ProductSet(Set):
         return ProductSet(a.intersect(b)
                 for a, b in zip(self.sets, other.sets))
 
+    def _union(self, other):
+        if not other.is_ProductSet:
+            return None
+        if len(other.args) != len(self.args):
+            return None
+        if self.args[0] == other.args[0]:
+            return self.args[0] * Union(ProductSet(self.args[1:]),
+                                        ProductSet(other.args[1:]))
+        if self.args[-1] == other.args[-1]:
+            return Union(ProductSet(self.args[:-1]),
+                         ProductSet(other.args[:-1])) * self.args[-1]
+        return None
+
     @property
     def sets(self):
         return self.args
@@ -384,6 +451,13 @@ class ProductSet(Set):
         # Union of all combinations but this one
         return Union(p for p in product_sets if p != self)
 
+    @property
+    def _boundary(self):
+        return Union(ProductSet(b + b.boundary if i != j else b.boundary
+                                for j, b in enumerate(self.sets))
+                                for i, a in enumerate(self.sets))
+
+
     @property
     def is_real(self):
         return all(set.is_real for set in self.sets)
@@ -627,6 +701,10 @@ class Interval(Set, EvalfMixin):
         b = Interval(self.end, S.Infinity, not self.right_open, True)
         return Union(a, b)
 
+    @property
+    def _boundary(self):
+        return FiniteSet(self.start, self.end)
+
     def _contains(self, other):
         if self.left_open:
             expr = other > self.start
@@ -641,20 +719,72 @@ class Interval(Set, EvalfMixin):
         return expr
 
     def _eval_imageset(self, f):
-        # Cut out 0, perform image, add back in image of 0
-        if self.contains(0) == True:
-            return imageset(f, self - FiniteSet(0)) + imageset(f, FiniteSet(0))
-
+        from sympy import Dummy
         from sympy.functions.elementary.miscellaneous import Min, Max
-        # TODO: manage left_open and right_open better in case of
-        # non-comparable left/right (e.g. Interval(x, y))
-        _left, _right = f(self.left), f(self.right)
-        left, right = Min(_left, _right), Max(_left, _right)
-        if _right == left: # switch happened
-            left_open, right_open = self.right_open, self.left_open
+        from sympy.solvers import solve
+        from sympy.core.function import diff
+        from sympy.series import limit
+        from sympy.calculus.singularities import singularities
+        # TODO: handle piecewise defined functions
+        # TODO: handle functions with infinitely many solutions (eg, sin, tan)
+        # TODO: handle multivariate functions
+
+        # var and expr are being defined this way to
+        # support Python lambda and not just sympy Lambda
+        try:
+            var = Dummy()
+            expr = f(var)
+            if len(expr.free_symbols) > 1:
+                raise TypeError
+        except TypeError:
+            raise NotImplementedError("Sorry, Multivariate imagesets are"
+                                      " not yet implemented, you are welcome"
+                                      " to add this feature in Sympy")
+
+        if not self.start.is_comparable or not self.end.is_comparable:
+            raise NotImplementedError("Sets with non comparable/variable"
+                                      " arguments are not supported")
+
+        sing = [x for x in singularities(expr, var) if x.is_real and x in self]
+
+        if self.left_open:
+            _start = limit(expr, var, self.start, dir="+")
+        elif self.start not in sing:
+            _start = f(self.start)
+        if self.right_open:
+            _end = limit(expr, var, self.end, dir="-")
+        elif self.end not in sing:
+            _end = f(self.end)
+
+        if len(sing) == 0:
+            solns = solve(diff(expr, var), var)
+
+            extr = [_start, _end] + [f(x) for x in solns
+                                     if x.is_real and x in self]
+            start, end = Min(*extr), Max(*extr)
+
+            left_open, right_open = False, False
+            if _start <= _end:
+                # the minimum or maximum value can occur simultaneously
+                # on both the edge of the interval and in some interior
+                # point
+                if start == _start and start not in solns:
+                    left_open = self.left_open
+                if end == _end and end not in solns:
+                    right_open = self.right_open
+            else:
+                if start == _end and start not in solns:
+                    left_open = self.right_open
+                if end == _start and end not in solns:
+                    right_open = self.left_open
+
+            return Interval(start, end, left_open, right_open)
         else:
-            left_open, right_open = self.left_open, self.right_open
-        return Interval(left, right, left_open, right_open)
+            return imageset(f, Interval(self.start, sing[0],
+                                        self.left_open, True)) + \
+                Union(*[imageset(f, Interval(sing[i], sing[i + 1]), True, True)
+                        for i in range(1, len(sing) - 1)]) + \
+                imageset(f, Interval(sing[-1], self.end, True, self.right_open))
 
     @property
     def _measure(self):
@@ -665,7 +795,7 @@ class Interval(Set, EvalfMixin):
 
     def _eval_evalf(self, prec):
         return Interval(self.left.evalf(), self.right.evalf(),
-          left_open=self.left_open, right_open=self.right_open)
+                        left_open=self.left_open, right_open=self.right_open)
 
     def _is_comparable(self, other):
         is_comparable = self.start.is_comparable
@@ -878,6 +1008,17 @@ class Union(Set, EvalfMixin):
             parity *= -1
         return measure
 
+    @property
+    def _boundary(self):
+        def boundary_of_set(i):
+            """ The boundary of set i minus interior of all other sets """
+            b = self.args[i].boundary
+            for j, a in enumerate(self.args):
+                if j != i:
+                    b = b - a.interior
+            return b
+        return Union(map(boundary_of_set, range(len(self.args))))
+
     def _eval_imageset(self, f):
         return Union(imageset(f, arg) for arg in self.args)
 
@@ -1112,6 +1253,10 @@ class EmptySet(with_metaclass(Singleton, Set)):
     def _eval_imageset(self, f):
         return self
 
+    @property
+    def _boundary(self):
+        return self
+
 class UniversalSet(with_metaclass(Singleton, Set)):
     """
     Represents the set of all things.
@@ -1159,6 +1304,10 @@ class UniversalSet(with_metaclass(Singleton, Set)):
     def _union(self, other):
         return self
 
+    @property
+    def _boundary(self):
+        return EmptySet()
+
 
 class FiniteSet(Set, EvalfMixin):
     """
@@ -1275,6 +1424,10 @@ class FiniteSet(Set, EvalfMixin):
         intervals.append(Interval(args[-1], S.Infinity, True, True))
         return Union(intervals, evaluate=False)
 
+    @property
+    def _boundary(self):
+        return self
+
     @property
     def _inf(self):
         from sympy.functions.elementary.miscellaneous import Min
@@ -1318,6 +1471,19 @@ class FiniteSet(Set, EvalfMixin):
         from sympy.utilities import default_sort_key
         return sorted(self.args, key=default_sort_key)
 
+    def __ge__(self, other):
+        return self.subset(other)
+
+    def __gt__(self, other):
+        return self != other and self >= other
+
+    def __le__(self, other):
+        return other.subset(self)
+
+    def __lt__(self, other):
+        return self != other and other >= self
+
+
 def imageset(*args):
     """ Image of set under transformation ``f``
 
