@@ -2,7 +2,7 @@ from __future__ import division
 
 from sympy import (Symbol, sin, cos, exp, sqrt, Rational, Float, re, pi,
         sympify, Add, Mul, Pow, Mod, I, log, S, Max, Or, symbols, oo, Integer,
-        sign, im
+        sign, im, nan
 )
 from sympy.core.compatibility import long
 from sympy.utilities.pytest import XFAIL, raises
@@ -936,6 +936,11 @@ def test_Pow_is_real():
     assert (i**o).is_real is False
     assert (i**k).is_real is None
 
+    x = Symbol("x", nonnegative=True)
+    y = Symbol("y", nonnegative=True)
+    assert im(x**y).expand(complex=True) is S.Zero
+    assert (x**y).is_real
+
 
 def test_real_Pow():
     k = Symbol('k', integer=True, nonzero=True)
@@ -1114,6 +1119,14 @@ def test_Mul_is_imaginary_real():
     assert (r*i*ii).is_imaginary is False
     assert (r*i*ii).is_real is True
 
+    # Github's issue 2775:
+    nr = Symbol('nr', real=False)
+    a = Symbol('a', real=True, nonzero=True)
+    b = Symbol('b', real=True)
+    assert (i*nr).is_real is None
+    assert (a*nr).is_real is False
+    assert (b*nr).is_real is None
+
 
 def test_Add_is_comparable():
     assert (x + y).is_comparable is False
@@ -1483,6 +1496,15 @@ def test_mul_flatten_oo():
     assert x_im*oo != I*oo  # i could be +/- 3*I -> +/-oo
 
 
+def test_add_flatten():
+    # see https://github.com/sympy/sympy/issues/2633#issuecomment-29545524
+    a = oo + I*oo
+    b = oo - I*oo
+    assert a + b == nan
+    assert a - b == nan
+    assert (1/a).simplify() == (1/b).simplify() == 0
+
+
 def test_issue_2061_2988_2990_2991():
     #2988
     assert ((-2*x*y**y)**3.2).n(2) == (2**3.2*(-x*y**y)**3.2).n(2)
