@@ -69,12 +69,14 @@ def test_power():
 
 
 def test_match_exclude():
-
     x = Symbol('x')
     y = Symbol('y')
-    p = Wild("p", exclude=[x, y])
-    q = Wild("q", exclude=[x, y])
-    r = Wild("r", exclude=[x, y])
+    p = Wild("p")
+    q = Wild("q")
+    r = Wild("r")
+
+    e = Rational(6)
+    assert e.match(2*p) == {p: 3}
 
     e = 3/(4*x + 5)
     assert e.match(3/(p*x + q)) == {p: 4, q: 5}
@@ -94,6 +96,20 @@ def test_match_exclude():
     e = 4*x + 5*y + 6
     assert e.match(p*x + q*y + r) == {p: 4, q: 5, r: 6}
 
+    a = Wild('a', exclude=[x])
+
+    e = 3*x
+    assert e.match(p*x) == {p: 3}
+    assert e.match(a*x) == {a: 3}
+
+    e = 3*x**2
+    assert e.match(p*x) == {p: 3*x}
+    assert e.match(a*x) is None
+
+    e = 3*x + 3 + 6/x
+    assert e.match(p*x**2 + p*x + 2*p) == {p: 3/x}
+    assert e.match(a*x**2 + a*x + 2*a) is None
+
 
 def test_mul():
     x, y, a, b, c = map(Symbol, 'xyabc')
@@ -165,10 +181,6 @@ def test_complex():
     assert (a*I).match(x*I) == {x: a}
     assert (a*I).match(x*y) == {x: I, y: a}
     assert (2*I).match(x*y) == {x: 2, y: I}
-
-    #Result is ambiguous, so we need to use Wild's exclude keyword
-    x = Wild('x', exclude=[I])
-    y = Wild('y', exclude=[I])
     assert (a + b*I).match(x + y*I) == {x: a, y: b}
 
 
@@ -223,8 +235,6 @@ def test_derivative1():
     assert (fd + 1).match(p + 1) == {p: fd}
     assert (fd).match(fd) == {}
     assert (3*fd).match(p*fd) is not None
-    p = Wild("p", exclude=[x])
-    q = Wild("q", exclude=[x])
     assert (3*fd - 1).match(p*fd + q) == {p: 3, q: -1}
 
 
@@ -308,28 +318,6 @@ def test_match_bug6():
     assert e.match(3*p*x) == {p: Rational(1)/3}
 
 
-def test_behavior1():
-    x = Symbol('x')
-    p = Wild('p')
-    e = 3*x**2
-    a = Wild('a', exclude=[x])
-    assert e.match(a*x) is None
-    assert e.match(p*x) == {p: 3*x}
-
-
-def test_behavior2():
-    x = Symbol('x')
-    p = Wild('p')
-
-    e = Rational(6)
-    assert e.match(2*p) == {p: 3}
-
-    e = 3*x + 3 + 6/x
-    a = Wild('a', exclude=[x])
-    assert e.expand().match(a*x**2 + a*x + 2*a) is None
-    assert e.expand().match(p*x**2 + p*x + 2*p) == {p: 3/x}
-
-
 def test_match_polynomial():
     x = Symbol('x')
     a = Wild('a', exclude=[x])
@@ -348,7 +336,7 @@ def test_match_polynomial():
 def test_exclude():
     x, y, a = map(Symbol, 'xya')
     p = Wild('p', exclude=[1, x])
-    q = Wild('q', exclude=[x])
+    q = Wild('q')
     r = Wild('r', exclude=[sin, y])
 
     assert sin(x).match(r) is None
