@@ -519,8 +519,6 @@ class harmonic(Function):
     # order and store it in a dictionary
     _functions = {}
 
-    nargs = (1, 2)
-
     @classmethod
     def eval(cls, n, m=None):
         if m is None:
@@ -626,8 +624,6 @@ class euler(Function):
     bell, bernoulli, catalan, fibonacci, harmonic, lucas
     """
 
-    nargs = 1
-
     @classmethod
     def eval(cls, m, evaluate=True):
         if not evaluate:
@@ -1056,7 +1052,8 @@ def nC(n, k=None, replacement=False):
             if not replacement:
                 return 2**n
             return sum(nC(n, i, replacement) for i in range(n + 1))
-        assert k >= 0
+        if k < 0:
+            raise ValueError("k cannot be negative")
         if replacement:
             return binomial(n + k - 1, k)
         return binomial(n, k)
@@ -1245,9 +1242,10 @@ def nT(n, k=None):
         sequence - converted to a multiset internally
         multiset - {element: multiplicity}
 
-    Note: the convention for ``nT`` is different than that of ``nC`` and``nP`` in that
+    Note: the convention for ``nT`` is different than that of ``nC`` and
+    ``nP`` in that
     here an integer indicates ``n`` *identical* items instead of a set of
-    length ``n``; this is in keepng with the ``partitions`` function which
+    length ``n``; this is in keeping with the ``partitions`` function which
     treats its integer-``n`` input like a list of ``n`` 1s. One can use
     ``range(n)`` for ``n`` to indicate ``n`` distinct items.
 
@@ -1266,9 +1264,7 @@ def nT(n, k=None):
     >>> nT('aabbc') == sum(_)
     True
 
-    (TODO The following can be activated with >>> when
-    taocp_multiset_permutation is in place.)
-    >> [nT("mississippi", i) for i in range(1, 12)]
+    >>> [nT("mississippi", i) for i in range(1, 12)]
     [1, 74, 609, 1521, 1768, 1224, 579, 197, 50, 9, 1]
 
     Partitions when all items are identical:
@@ -1296,7 +1292,7 @@ def nT(n, k=None):
     sympy.utilities.iterables.multiset_partitions
 
     """
-    from sympy.utilities.iterables import multiset_partitions
+    from sympy.utilities.enumerative import MultisetPartitionTraverser
 
     if isinstance(n, SYMPY_INTS):
         # assert n >= 0
@@ -1334,10 +1330,12 @@ def nT(n, k=None):
         if k is None:
             return bell(N)
         return stirling(N, k)
+    m = MultisetPartitionTraverser()
     if k is None:
-        return sum(nT(n, k) for k in range(1, N + 1))
+        return m.count_partitions(n[_M])
+    # MultisetPartitionTraverser does not have a range-limited count
+    # method, so need to enumerate and count
     tot = 0
-    for p in multiset_partitions(
-            [i for i, j in enumerate(n[_M]) for ii in range(j)]):
-        tot += len(p) == k
+    for discard in m.enum_range(n[_M], k-1, k):
+        tot += 1
     return tot
