@@ -184,7 +184,7 @@ class GA_Printer(StrPrinter):
     def _print_Function(self, expr):
         name = expr.func.__name__
 
-        if expr.func.nargs is not None:
+        if expr.args:
             if name in GA_Printer.function_names:
                 return expr.func.__name__ + "(%s)" % self.stringify(expr.args, ", ")
 
