@@ -10,16 +10,22 @@ from __future__ import print_function, division
 
 from sympy.core import S, C, sympify, pi, Dummy
 from sympy.core.logic import fuzzy_bool
-from sympy.core.numbers import oo
+from sympy.core.numbers import oo, zoo
 from sympy.simplify import simplify, trigsimp
 from sympy.functions.elementary.miscellaneous import sqrt, Max, Min
 from sympy.functions.elementary.complexes import im
 from sympy.geometry.exceptions import GeometryError
+from sympy.polys import Poly, PolynomialError
 from sympy.solvers import solve
+from sympy.utilities.lambdify import lambdify
+from sympy.utilities.iterables import uniq
+from sympy.utilities.misc import filldedent
 from .entity import GeometryEntity
 from .point import Point
 from .line import LinearEntity, Line
 from .util import _symbol, idiff
+from sympy.mpmath import findroot as nroot
+
 
 import random
 
@@ -478,7 +484,8 @@ class Ellipse(GeometryEntity):
         if hr == vr:
             return (c, c)
 
-        # calculate focus distance manually, since focus_distance calls this routine
+        # calculate focus distance manually, since focus_distance calls this
+        # routine
         fd = sqrt(self.major**2 - self.minor**2)
         if hr == self.minor:
             # foci on the y-axis
@@ -534,12 +541,50 @@ class Ellipse(GeometryEntity):
         >>> from sympy import Circle, Line
         >>> Circle((0, 1), 1).reflect(Line((0, 0), (1, 1)))
         Circle(Point(1, 0), -1)
+        >>> from sympy import Ellipse, Line, Point
+        >>> Ellipse(Point(3, 4), 1, 3).reflect(Line(Point(0, -4), Point(5, 0)))
+        Traceback (most recent call last):
+        ...
+        NotImplementedError:
+        General Ellipse is not supported but the equation of the reflected
+        Ellipse is given by the zeros of: f(x, y) = (9*x/41 + 40*y/41 +
+        37/41)**2 + (40*x/123 - 3*y/41 - 364/123)**2 - 1
+
+        Notes
+        =====
+
+        Until the general ellipse (with no axis parallel to the x-axis) is
+        supported a NotImplemented error is raised and the equation whose
+        zeros define the rotated ellipse is given.
+
         """
+        def _uniquely_named_symbol(xname, *exprs):
+            """Return a symbol which, when printed, will have a name unique
+            from any other already in the expressions given. The name is made
+            unique by prepending underscores.
+            """
+            prefix = '%s'
+            x = prefix % xname
+            syms = set.union(*[e.free_symbols for e in exprs])
+            while any(x == str(s) for s in syms):
+                prefix = '_' + prefix
+                x = prefix % xname
+            return _symbol(x)
+
         if line.slope in (0, oo):
             c = self.center
             c = c.reflect(line)
             return self.func(c, -self.hradius, self.vradius)
-        raise NotImplementedError('reflection line not horizontal | vertical.')
+        else:
+            x, y = [_uniquely_named_symbol(name, self, line) for name in 'xy']
+            expr = self.equation(x, y)
+            p = Point(x, y).reflect(line)
+            result = expr.subs(zip((x, y), p.args
+                               ), simultaneous=True)
+            raise NotImplementedError(filldedent(
+                'General Ellipse is not supported but the equation '
+                'of the reflected Ellipse is given by the zeros of: ' +
+                "f(%s, %s) = %s" % (str(x), str(y), str(result))))
 
     def encloses_point(self, p):
         """
@@ -641,6 +686,7 @@ class Ellipse(GeometryEntity):
         >>> p[1] = t # doctest: +SKIP
 
         """
+        p = Point(p)
         if self.encloses_point(p):
             return []
 
@@ -739,6 +785,92 @@ class Ellipse(GeometryEntity):
         else:
             raise NotImplementedError("Unknown argument type")
 
+    def normal_lines(self, p, prec=None):
+        """Normal lines between `p` and the ellipse.
+
+        Parameters
+        ==========
+
+        p : Point
+
+        Returns
+        =======
+
+        normal_lines : list with 1, 2 or 4 Lines
+
+        Examples
+        ========
+
+        >>> from sympy import Line, Point, Ellipse
+        >>> e = Ellipse((0, 0), 2, 3)
+        >>> c = e.center
+        >>> e.normal_lines(c + Point(1, 0))
+        [Line(Point(0, 0), Point(1, 0))]
+        >>> e.normal_lines(c)
+        [Line(Point(0, 0), Point(0, 1)), Line(Point(0, 0), Point(1, 0))]
+
+        Off-axis points require the solution of a quartic equation. This
+        often leads to very large expressions that may be of little practical
+        use. An approximate solution of `prec` digits can be obtained by
+        passing in the desired value:
+
+        >>> e.normal_lines((3, 3), prec=2)
+        [Line(Point(-38/47, -85/31), Point(9/47, -21/17)),
+        Line(Point(19/13, -43/21), Point(32/13, -8/3))]
+
+        Whereas the above solution has an operation count of 12, the exact
+        solution has an operation count of 2020.
+        """
+        p = Point(p)
+
+        # XXX change True to something like self.angle == 0 if the arbitrarily
+        # rotated ellipse is introduced.
+        # https://github.com/sympy/sympy/issues/2815)
+        if True:
+            rv = []
+            if p.x == self.center.x:
+                rv.append(Line(self.center, slope=oo))
+            if p.y == self.center.y:
+                rv.append(Line(self.center, slope=0))
+            if rv:
+                # at these special orientations of p either 1 or 2 normals
+                # exist and we are done
+                return rv
+
+        # find the 4 normal points and construct lines through them with
+        # the corresponding slope
+        x, y = Dummy('x', real=True), Dummy('y', real=True)
+        eq = self.equation(x, y)
+        dydx = idiff(eq, y, x)
+        norm = -1/dydx
+        slope = Line(p, (x, y)).slope
+        seq = slope - norm
+        points = []
+        if prec is not None:
+            yis = solve(seq, y)[0]
+            xeq = eq.subs(y, yis).as_numer_denom()[0].expand()
+            try:
+                iv = list(zip(*Poly(xeq).intervals()))[0]
+                # bisection is safest here since other methods may miss root
+                xsol = [S(nroot(lambdify(x, xeq), i, solver="anderson"))
+                    for i in iv]
+                points = [Point(i, solve(eq.subs(x, i), y)[0]).n(prec)
+                    for i in xsol]
+            except PolynomialError:
+                pass
+        if not points:
+            points = [Point(*s) for s in solve((seq, eq), (x, y))]
+            # complicated expressions may not be decidably real so evaluate to
+            # check whether they are real or not
+            points = [i.n(prec) if prec is not None else i
+                for i in points if all(j.n(2).is_real for j in i.args)]
+        slopes = [norm.subs(zip((x, y), pt.args)) for pt in points]
+        if prec is not None:
+            slopes = [i.n(prec) if i not in (-oo, oo, zoo) else i
+                for i in slopes]
+        return [Line(pt, slope=s) for pt,s in zip(points, slopes)]
+
+
     def arbitrary_point(self, parameter='t'):
         """A parameterized point on the ellipse.
 
@@ -775,7 +907,8 @@ class Ellipse(GeometryEntity):
         """
         t = _symbol(parameter)
         if t.name in (f.name for f in self.free_symbols):
-            raise ValueError('Symbol %s already appears in object and cannot be used as a parameter.' % t.name)
+            raise ValueError(filldedent('Symbol %s already appears in object '
+                'and cannot be used as a parameter.' % t.name))
         return Point(self.center.x + self.hradius*C.cos(t),
                      self.center.y + self.vradius*C.sin(t))
 
@@ -860,11 +993,11 @@ class Ellipse(GeometryEntity):
         >>> p2 in e1
         False
 
-        Note that arbitrary_point routine does not take this approach. A value for
-        cos(t) and sin(t) (not t) is substituted into the arbitrary point. There is
-        a small chance that this will give a point that will not test as being
-        in the ellipse, so the process is repeated (up to 10 times) until a
-        valid point is obtained.
+        Note that arbitrary_point routine does not take this approach. A value
+        for cos(t) and sin(t) (not t) is substituted into the arbitrary point.
+        There is a small chance that this will give a point that will not
+        test as being in the ellipse, so the process is repeated (up to 10
+        times) until a valid point is obtained.
 
         """
         from sympy import sin, cos, Rational
@@ -965,43 +1098,20 @@ class Ellipse(GeometryEntity):
 
         return [r for r in result if r in o]
 
-    def _do_circle_intersection(self, o):
-        """The intersection of an Ellipse and a Circle.
-
-        Private helper method for `intersection`.
-
-        """
-        variables = self.equation().atoms(C.Symbol)
-        if len(variables) > 2:
-            return None
-        if self.center == o.center:
-            a, b, r = o.major, o.minor, self.radius
-            x = a*sqrt(simplify((r**2 - b**2)/(a**2 - b**2)))
-            y = b*sqrt(simplify((a**2 - r**2)/(a**2 - b**2)))
-            return list(set([Point(x, y), Point(x, -y), Point(-x, y),
-                             Point(-x, -y)]))
-        else:
-            x, y = variables
-            xx = solve(self.equation(), x)
-            intersect = []
-            for xi in xx:
-                yy = solve(o.equation().subs(x, xi), y)
-                for yi in yy:
-                    intersect.append(Point(xi, yi))
-            return list(set(intersect))
-
     def _do_ellipse_intersection(self, o):
-        """The intersection of two ellipses.
+        """The intersection of an ellipse with another ellipse or a circle.
 
         Private helper method for `intersection`.
 
         """
-        x = Dummy('x')
-        y = Dummy('y')
+
+        x = Dummy('x', real=True)
+        y = Dummy('y', real=True)
         seq = self.equation(x, y)
         oeq = o.equation(x, y)
         result = solve([seq, oeq], [x, y])
-        return [Point(*r) for r in result if im(r[0]).is_zero is not False and im(r[1]).is_zero is not False]
+        return [Point(*r) for r in list(uniq(result))]
+
 
     def intersection(self, o):
         """The intersection of this ellipse and another geometrical entity
@@ -1050,11 +1160,10 @@ class Ellipse(GeometryEntity):
         >>> e.intersection(Ellipse(Point(100500, 0), 4, 3))
         []
         >>> e.intersection(Ellipse(Point(0, 0), 3, 4))
-        [Point(-363/175, -48*sqrt(111)/175), Point(-363/175, 48*sqrt(111)/175),
-        Point(3, 0)]
+        [Point(-363/175, -48*sqrt(111)/175), Point(-363/175, 48*sqrt(111)/175), Point(3, 0)]
+
         >>> e.intersection(Ellipse(Point(-1, 0), 3, 4))
-        [Point(-17/5, -12/5), Point(-17/5, 12/5), Point(7/5, -12/5),
-        Point(7/5, 12/5)]
+        [Point(-17/5, -12/5), Point(-17/5, 12/5), Point(7/5, -12/5), Point(7/5, 12/5)]
         """
         if isinstance(o, Point):
             if o in self:
@@ -1068,7 +1177,7 @@ class Ellipse(GeometryEntity):
             return self._do_line_intersection(o)
 
         elif isinstance(o, Circle):
-            return self._do_circle_intersection(o)
+            return self._do_ellipse_intersection(o)
 
         elif isinstance(o, Ellipse):
             if o == self:
