@@ -52,8 +52,6 @@ class IntegralTransform(Function):
     number and possibly a convergence condition.
     """
 
-    nargs = 3
-
     @property
     def function(self):
         """ The function to be transformed. """
@@ -668,7 +666,8 @@ def _rewrite_gamma(f, s, a, b):
                 p = abs(S(a))
                 newa = a/p
                 newc = c/p
-                assert a.is_Integer
+                if not a.is_Integer:
+                    raise TypeError("a is not an integer")
                 for k in range(p):
                     gammas += [(newa, newc + k/p)]
                 if is_numer:
@@ -768,8 +767,6 @@ class InverseMellinTransform(IntegralTransform):
     :func:`inverse_mellin_transform` docstring.
     """
 
-    nargs = 5
-
     _name = 'Inverse Mellin'
     _none_sentinel = Dummy('None')
     _c = Dummy('c')
@@ -1068,13 +1065,6 @@ class LaplaceTransform(IntegralTransform):
         from sympy import Integral, exp
         return Integral(f*exp(-s*t), (t, 0, oo))
 
-    """
-    Class representing unevaluated Laplace transforms.
-
-    For usage of this class, see the :class:`IntegralTransform` docstring.
-    For how to compute Laplace transforms, see the :func:`laplace_transform`
-    docstring.
-    """
     def _collapse_extra(self, extra):
         from sympy import And, Max
         conds = []
@@ -1205,8 +1195,6 @@ class InverseLaplaceTransform(IntegralTransform):
     :func:`inverse_laplace_transform` docstring.
     """
 
-    nargs = 4
-
     _name = 'Inverse Laplace'
     _none_sentinel = Dummy('None')
     _c = Dummy('c')
@@ -1702,8 +1690,6 @@ class HankelTypeTransform(IntegralTransform):
     Base class for Hankel transforms.
     """
 
-    nargs = 4
-
     def doit(self, **hints):
         return self._compute_transform(self.function,
                                        self.function_variable,
