@@ -11,7 +11,7 @@ from sympy.matrices import (
     SparseMatrix, casoratian, diag, eye, hessian,
     matrix_multiply_elementwise, ones, randMatrix, rot_axis1, rot_axis2,
     rot_axis3, wronskian, zeros)
-from sympy.core.compatibility import long
+from sympy.core.compatibility import long, iterable
 from sympy.utilities.iterables import flatten, capture
 from sympy.utilities.pytest import raises, XFAIL, slow
 
@@ -62,6 +62,50 @@ def test_addition():
     assert a + b == a.add(b) == Matrix([[2, 4], [6, 1]])
 
 
+def test_fancy_index_matrix():
+    for M in (Matrix, SparseMatrix):
+        a = M(3, 3, range(9))
+        assert a == a[:, :]
+        assert a[1, :] == Matrix(1, 3, [3, 4, 5])
+        assert a[:, 1] == Matrix([1, 4, 7])
+        assert a[[0, 1], :] == Matrix([[0, 1, 2], [3, 4, 5]])
+        assert a[[0, 1], 2] == a[[0, 1], [2]]
+        assert a[2, [0, 1]] == a[[2], [0, 1]]
+        assert a[:, [0, 1]] == Matrix([[0, 1], [3, 4], [6, 7]])
+        assert a[0, 0] == 0
+        assert a[0:2, :] == Matrix([[0, 1, 2], [3, 4, 5]])
+        assert a[:, 0:2] == Matrix([[0, 1], [3, 4], [6, 7]])
+        assert a[::2, 1] == a[[0, 2], 1]
+        assert a[1, ::2] == a[1, [0, 2]]
+        a = M(3, 3, range(9))
+        assert a[[0, 2, 1, 2, 1], :] == Matrix([
+            [0, 1, 2],
+            [6, 7, 8],
+            [3, 4, 5],
+            [6, 7, 8],
+            [3, 4, 5]])
+        assert a[:, [0,2,1,2,1]] == Matrix([
+            [0, 2, 1, 2, 1],
+            [3, 5, 4, 5, 4],
+            [6, 8, 7, 8, 7]])
+
+    a = SparseMatrix.zeros(3)
+    a[1, 2] = 2
+    a[0, 1] = 3
+    a[2, 0] = 4
+    assert a.extract([1, 1], [2]) == Matrix([
+    [2],
+    [2]])
+    assert a.extract([1, 0], [2, 2, 2]) == Matrix([
+    [2, 2, 2],
+    [0, 0, 0]])
+    assert a.extract([1, 0, 1, 2], [2, 0, 1, 0]) == Matrix([
+        [2, 0, 0, 0],
+        [0, 0, 3, 0],
+        [2, 0, 0, 0],
+        [0, 4, 0, 4]])
+
+
 def test_multiplication():
     a = Matrix((
         (1, 2),
@@ -139,6 +183,8 @@ def test_creation():
     with raises(IndexError):
         Matrix((1, 2))[3] = 5
 
+    assert Matrix() == Matrix([]) == Matrix([[]]) == Matrix(0, 0, [])
+
     a = Matrix([[x, 0], [0, 0]])
     m = a
     assert m.cols == m.rows
@@ -347,7 +393,7 @@ def test_berkowitz_minors():
     assert B.berkowitz_minors() == (1, -3)
 
 
-def test_submatrix():
+def test_slicing():
     m0 = eye(4)
     assert m0[:3, :3] == eye(3)
     assert m0[2:4, 0:2] == zeros(2)
@@ -1936,6 +1982,13 @@ def test_is_zero():
     assert Matrix([[0, 0], [0, 0]]).is_zero
     assert zeros(3, 4).is_zero
     assert not eye(3).is_zero
+    assert Matrix([[x, 0], [0, 0]]).is_zero == None
+    assert SparseMatrix([[x, 0], [0, 0]]).is_zero == None
+    assert ImmutableMatrix([[x, 0], [0, 0]]).is_zero == None
+    assert ImmutableSparseMatrix([[x, 0], [0, 0]]).is_zero == None
+    assert Matrix([[x, 1], [0, 0]]).is_zero == False
+    a = Symbol('a', nonzero=True)
+    assert Matrix([[a, 0], [0, 0]]).is_zero == False
 
 
 def test_rotation_matrices():
@@ -1966,6 +2019,9 @@ def test_DeferredVector():
     assert str(DeferredVector("vector")[4]) == "vector[4]"
     assert sympify(DeferredVector("d")) == DeferredVector("d")
 
+def test_DeferredVector_not_iterable():
+    assert not iterable(DeferredVector('X'))
+
 def test_DeferredVector_Matrix():
     raises(TypeError, lambda: Matrix(DeferredVector("V")))
 
