@@ -27,14 +27,10 @@ from . import particle
 from .particle import *
 __all__.extend(particle.__all__)
 
-from . import point
-from .point import *
-__all__.extend(point.__all__)
-
-from . import essential
-from .essential import *
-__all__.extend(essential.__all__)
-
 from . import lagrange
 from .lagrange import *
 __all__.extend(lagrange.__all__)
+
+from sympy.physics import vector
+from sympy.physics.vector import *
+__all__.extend(vector.__all__)
