@@ -34,6 +34,7 @@ MATH_TRANSLATIONS = {
 }
 
 MPMATH_TRANSLATIONS = {
+    "Abs": "fabs",
     "elliptic_k": "ellipk",
     "elliptic_f": "ellipf",
     "elliptic_e": "ellipe",
@@ -142,7 +143,7 @@ def _import(module, reload="False"):
         namespace[sympyname] = namespace[translation]
 
 
-def lambdify(args, expr, modules=None, printer=None, use_imps=True):
+def lambdify(args, expr, modules=None, printer=None, use_imps=True, dummify=True):
     """
     Returns a lambda function for fast calculation of numerical values.
 
@@ -160,22 +161,25 @@ def lambdify(args, expr, modules=None, printer=None, use_imps=True):
     The default behavior is to substitute all arguments in the provided
     expression with dummy symbols. This allows for applied functions (e.g.
     f(t)) to be supplied as arguments. Call the function with dummify=False if
-    dummy substitution is unwanted.
-    If you want to view the lambdified function or provide "sympy" as the
-    module, you should probably set dummify=False.
+    dummy substitution is unwanted (and `args` is not a string). If you want
+    to view the lambdified function or provide "sympy" as the module, you
+    should probably set dummify=False.
 
     Usage
     =====
 
     (1) Use one of the provided modules:
 
-        >> f = lambdify(x, sin(x), "math")
+        >>> from sympy import lambdify, sin, gamma
+        >>> from sympy.utilities.lambdify import lambdastr
+        >>> from sympy.abc import x
+        >>> f = lambdify(x, sin(x), "math")
 
         Attention: Functions that are not in the math module will throw a name
                    error when the lambda function is evaluated! So this would
                    be better:
 
-        >> f = lambdify(x, sin(x)*gamma(x), ("math", "mpmath", "sympy"))
+        >>> f = lambdify(x, sin(x)*gamma(x), ("math", "mpmath", "sympy"))
 
     (2) Use some other module:
 
@@ -194,15 +198,12 @@ def lambdify(args, expr, modules=None, printer=None, use_imps=True):
         >> f(array([1, 2, 3]), array([2, 3, 5]))
         [-2.18503986 -0.29100619 -0.8559934 ]
 
-    (3) Use own dictionaries:
+    (3) Use a dictionary defining custom functions:
 
-        >> def my_cool_function(x): ...
-        >> dic = {"sin" : my_cool_function}
-        >> f = lambdify(x, sin(x), dic)
-
-        Now f would look like:
-
-        >> lambda x: my_cool_function(x)
+        >>> def my_cool_function(x): return 'sin(%s) is cool' % x
+        >>> myfuncs = {"sin" : my_cool_function}
+        >>> f = lambdify(x, sin(x), myfuncs); f(1)
+        'sin(1) is cool'
 
     Examples
     ========
@@ -210,7 +211,7 @@ def lambdify(args, expr, modules=None, printer=None, use_imps=True):
     >>> from sympy.utilities.lambdify import implemented_function, lambdify
     >>> from sympy import sqrt, sin, Matrix
     >>> from sympy import Function
-    >>> from sympy.abc import x, y, z
+    >>> from sympy.abc import w, x, y, z
 
     >>> f = lambdify(x, x**2)
     >>> f(2)
@@ -224,10 +225,28 @@ def lambdify(args, expr, modules=None, printer=None, use_imps=True):
     >>> f = lambdify((x, y), sin(x*y)**2)
     >>> f(0, 5)
     0.0
-    >>> f = lambdify((x, y), Matrix((x, x + y)).T, modules='sympy')
-    >>> f(1, 2)
+    >>> row = lambdify((x, y), Matrix((x, x + y)).T, modules='sympy')
+    >>> row(1, 2)
     Matrix([[1, 3]])
 
+    Tuple arguments are handled and the lambdified function should
+    be called with the same type of arguments as were used to create
+    the function.:
+
+    >>> f = lambdify((x, (y, z)), x + y)
+    >>> f(1, (2, 4))
+    3
+
+    A more robust way of handling this is to always work with flattened
+    arguments:
+
+    >>> from sympy.utilities.iterables import flatten
+    >>> args = w, (x, (y, z))
+    >>> vals = 1, (2, (3, 4))
+    >>> f = lambdify(flatten(args), w + x + y + z)
+    >>> f(*flatten(vals))
+    10
+
     Functions present in `expr` can also carry their own numerical
     implementations, in a callable attached to the ``_imp_``
     attribute.  Usually you attach this using the
@@ -242,6 +261,7 @@ def lambdify(args, expr, modules=None, printer=None, use_imps=True):
     in other namespaces, unless the ``use_imps`` input parameter is False.
     """
     from sympy.core.symbol import Symbol
+    from sympy.utilities.iterables import flatten
 
     # If the user hasn't specified any modules, use what is available.
     module_provided = True
@@ -284,7 +304,11 @@ def lambdify(args, expr, modules=None, printer=None, use_imps=True):
             namespace.update({str(term): term})
 
     # Create lambda function.
-    lstr = lambdastr(args, expr, printer=printer, dummify=True)
+    lstr = lambdastr(args, expr, printer=printer, dummify=dummify)
+    flat = '__flatten_args__'
+    if flat in lstr:
+        import itertools
+        namespace.update({flat: flatten})
     return eval(lstr, namespace)
 
 
@@ -307,6 +331,9 @@ def lambdastr(args, expr, printer=None, dummify=False):
     """
     Returns a string that can be evaluated to a lambda function.
 
+    Examples
+    ========
+
     >>> from sympy.abc import x, y, z
     >>> from sympy.utilities.lambdify import lambdastr
     >>> lambdastr(x, x**2)
@@ -314,10 +341,16 @@ def lambdastr(args, expr, printer=None, dummify=False):
     >>> lambdastr((x,y,z), [z,y,x])
     'lambda x,y,z: ([z, y, x])'
 
+    Although tuples may not appear as arguments to lambda in Python 3,
+    lambdastr will create a lambda function that will unpack the original
+    arguments so that nested arguments can be handled:
+
+    >>> lambdastr((x, (y, z)), x + y)
+    'lambda _0,_1: (lambda x,y,z: (x + y))(*list(__flatten_args__([_0,_1])))'
     """
     # Transforming everything to strings.
     from sympy.matrices import DeferredVector
-    from sympy import Dummy, sympify, Symbol, Function
+    from sympy import Dummy, sympify, Symbol, Function, flatten
 
     if printer is not None:
         if inspect.isfunction(printer):
@@ -337,8 +370,6 @@ def lambdastr(args, expr, printer=None, dummify=False):
         elif isinstance(args, DeferredVector):
             return str(args)
         elif iterable(args):
-            flatten = lambda *n: (e for a in n for e in
-                                  (flatten(*a) if iterable(a) else (a,)))
             dummies = flatten([sub_args(a, dummies_dict) for a in args])
             return ",".join(str(a) for a in dummies)
         else:
@@ -366,6 +397,22 @@ def lambdastr(args, expr, printer=None, dummify=False):
         return expr
 
     # Transform args
+    def isiter(l):
+        return iterable(l, exclude=(str, DeferredVector))
+    if isiter(args) and any(isiter(i) for i in args):
+        from sympy.utilities.iterables import flatten
+        import re
+        dum_args = [str(Dummy(str(i))) for i in range(len(args))]
+        iter_args = ','.join([i if isiter(a) else i
+            for i, a in zip(dum_args, args)])
+        lstr = lambdastr(flatten(args), expr, printer=printer, dummify=dummify)
+        flat = '__flatten_args__'
+        rv = 'lambda %s: (%s)(*list(%s([%s])))' % (
+            ','.join(dum_args), lstr, flat, iter_args)
+        if len(re.findall(r'\b%s\b' % flat, rv)) > 1:
+            raise ValueError('the name %s is reserved by lambdastr' % flat)
+        return rv
+
     dummies_dict = {}
     if dummify:
         args = sub_args(args, dummies_dict)
