@@ -30,6 +30,7 @@ import random
 import subprocess
 import signal
 import stat
+from inspect import isgeneratorfunction
 
 from sympy.core.cache import clear_cache
 from sympy.core.compatibility import exec_, PY3, get_function_code, string_types
@@ -119,23 +120,6 @@ def sys_normcase(f):
     return f
 
 
-def isgeneratorfunction(object):
-    """
-    Return True if the object is a user-defined generator function.
-
-    Generator function objects provides same attributes as functions.
-
-    See isfunction.__doc__ for attributes listing.
-
-    Adapted from Python 2.6.
-    """
-    CO_GENERATOR = 0x20
-    if (inspect.isfunction(object) or inspect.ismethod(object)) and \
-            get_function_code(object).co_flags & CO_GENERATOR:
-        return True
-    return False
-
-
 def setup_pprint():
     from sympy import pprint_use_unicode, init_printing
 
